==> ejc-assistrmat-impl-3.0.0-20220322.020504-1-sources.jar: com/ejianc/business/assist/ownrmat/bean/AllotInDetailEntity.java <==
package com.ejianc.business.assist.ownrmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 周转材调入明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proownrmat_allot_in_detail")
public class AllotInDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="allocat_id")
    private Long allocatId; // 主表id
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类id
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value="material_id")
    private Long materialId; // 物资id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_spec")
    private String materialSpec; // 规格型号
    @TableField(value="material_unit_id")
    private Long materialUnitId; // 物资计量单位id
    @TableField(value="material_unit")
    private String materialUnit; // 物资计量单位
    @TableField(value="surplus_num")
    private BigDecimal surplusNum; // 剩余可用数量
    @TableField(value="allocat_num")
    private BigDecimal allocatNum; // 调拨数量
    @TableField(value="allocat_price")
    private BigDecimal allocatPrice; // 调拨单价
    @TableField(value="allocat_tax_price")
    private BigDecimal allocatTaxPrice; // 调拨单价（有税）
    @TableField(value="allocat_tax_rate")
    private BigDecimal allocatTaxRate; // 调拨税率
    @TableField(value="allocat_mny")
    private BigDecimal allocatMny; // 调拨金额
    @TableField(value="allocat_tax_mny")
    private BigDecimal allocatTaxMny; // 调拨单价（有税）
    @TableField(value="allocat_tax")
    private BigDecimal allocatTax; // 调拨税额
    @TableField(value="in_store_average_price")
    private BigDecimal inStoreAveragePrice; // 入库均价
    @TableField(value="in_store_tax")
    private BigDecimal inStoreTax; // 入库税额
    @TableField(value="in_store_mny")
    private BigDecimal inStoreMny; // 入库金额
    @TableField(value="in_store_tax_mny")
    private BigDecimal inStoreTaxMny; // 入库金额（有税）
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="in_store_tax_rate")
    private BigDecimal inStoreTaxRate; // 入库税率

    @TableField(value="net_worth_tax_mny")
    private BigDecimal netWorthTaxMny; // 材料净值(含税)
    @TableField(value="net_worth_mny")
    private BigDecimal netWorthMny; // 材料净值(无税)
    @TableField(value="original_value_tax_price")
    private BigDecimal originalValueTaxPrice; // 原值单价(含税)
    @TableField(value="original_value_price")
    private BigDecimal originalValuePrice; // 原值单价(无税)
    @TableField(value="original_value_tax_mny")
    private BigDecimal originalValueTaxMny; // 材料原值(含税)
    @TableField(value="original_value_mny")
    private BigDecimal originalValueMny; // 材料原值(无税)
    @TableField(value="on_hand_num")
    private BigDecimal onHandNum; // 在场数量
    @TableField(value="allocat_blance_mny")
    private BigDecimal allocatBlanceMny; // 调拨差额(无税)
    @TableField(value="allocat_blance_tax_mny")
    private BigDecimal allocatBlanceTaxMny; // 调拨差额
    @TableField(value="net_worth_tax")
    private BigDecimal netWorthTax; // 材料税额
    @TableField(value="net_worth_tax_rate")
    private BigDecimal netWorthTaxRate; // 材料税率
    

    public Long getAllocatId() {
        return allocatId;
    }

    public void setAllocatId(Long allocatId) {
        this.allocatId = allocatId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public Long getMaterialUnitId() {
        return materialUnitId;
    }

    public void setMaterialUnitId(Long materialUnitId) {
        this.materialUnitId = materialUnitId;
    }
    public String getMaterialUnit() {
        return materialUnit;
    }

    public void setMaterialUnit(String materialUnit) {
        this.materialUnit = materialUnit;
    }
    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }
    public BigDecimal getAllocatNum() {
        return allocatNum;
    }

    public void setAllocatNum(BigDecimal allocatNum) {
        this.allocatNum = allocatNum;
    }
    public BigDecimal getAllocatPrice() {
        return allocatPrice;
    }

    public void setAllocatPrice(BigDecimal allocatPrice) {
        this.allocatPrice = allocatPrice;
    }
    public BigDecimal getAllocatTaxPrice() {
        return allocatTaxPrice;
    }

    public void setAllocatTaxPrice(BigDecimal allocatTaxPrice) {
        this.allocatTaxPrice = allocatTaxPrice;
    }
    public BigDecimal getAllocatTaxRate() {
        return allocatTaxRate;
    }

    public void setAllocatTaxRate(BigDecimal allocatTaxRate) {
        this.allocatTaxRate = allocatTaxRate;
    }
    public BigDecimal getAllocatMny() {
        return allocatMny;
    }

    public void setAllocatMny(BigDecimal allocatMny) {
        this.allocatMny = allocatMny;
    }
    public BigDecimal getAllocatTaxMny() {
        return allocatTaxMny;
    }

    public void setAllocatTaxMny(BigDecimal allocatTaxMny) {
        this.allocatTaxMny = allocatTaxMny;
    }
    public BigDecimal getAllocatTax() {
        return allocatTax;
    }

    public void setAllocatTax(BigDecimal allocatTax) {
        this.allocatTax = allocatTax;
    }
    public BigDecimal getInStoreAveragePrice() {
        return inStoreAveragePrice;
    }

    public void setInStoreAveragePrice(BigDecimal inStoreAveragePrice) {
        this.inStoreAveragePrice = inStoreAveragePrice;
    }
    public BigDecimal getInStoreTax() {
        return inStoreTax;
    }

    public void setInStoreTax(BigDecimal inStoreTax) {
        this.inStoreTax = inStoreTax;
    }
    public BigDecimal getInStoreMny() {
        return inStoreMny;
    }

    public void setInStoreMny(BigDecimal inStoreMny) {
        this.inStoreMny = inStoreMny;
    }
    public BigDecimal getInStoreTaxMny() {
        return inStoreTaxMny;
    }

    public void setInStoreTaxMny(BigDecimal inStoreTaxMny) {
        this.inStoreTaxMny = inStoreTaxMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getInStoreTaxRate() {
        return inStoreTaxRate;
    }

    public void setInStoreTaxRate(BigDecimal inStoreTaxRate) {
        this.inStoreTaxRate = inStoreTaxRate;
    }

    public BigDecimal getNetWorthTaxMny() {
        return netWorthTaxMny;
    }

    public void setNetWorthTaxMny(BigDecimal netWorthTaxMny) {
        this.netWorthTaxMny = netWorthTaxMny;
    }

    public BigDecimal getNetWorthMny() {
        return netWorthMny;
    }

    public void setNetWorthMny(BigDecimal netWorthMny) {
        this.netWorthMny = netWorthMny;
    }

    public BigDecimal getOriginalValueTaxPrice() {
        return originalValueTaxPrice;
    }

    public void setOriginalValueTaxPrice(BigDecimal originalValueTaxPrice) {
        this.originalValueTaxPrice = originalValueTaxPrice;
    }

    public BigDecimal getOriginalValuePrice() {
        return originalValuePrice;
    }

    public void setOriginalValuePrice(BigDecimal originalValuePrice) {
        this.originalValuePrice = originalValuePrice;
    }

    public BigDecimal getOriginalValueTaxMny() {
        return originalValueTaxMny;
    }

    public void setOriginalValueTaxMny(BigDecimal originalValueTaxMny) {
        this.originalValueTaxMny = originalValueTaxMny;
    }

    public BigDecimal getOriginalValueMny() {
        return originalValueMny;
    }

    public void setOriginalValueMny(BigDecimal originalValueMny) {
        this.originalValueMny = originalValueMny;
    }

    public BigDecimal getOnHandNum() {
        return onHandNum;
    }

    public void setOnHandNum(BigDecimal onHandNum) {
        this.onHandNum = onHandNum;
    }

    public BigDecimal getAllocatBlanceMny() {
        return allocatBlanceMny;
    }

    public void setAllocatBlanceMny(BigDecimal allocatBlanceMny) {
        this.allocatBlanceMny = allocatBlanceMny;
    }

    public BigDecimal getAllocatBlanceTaxMny() {
        return allocatBlanceTaxMny;
    }

    public void setAllocatBlanceTaxMny(BigDecimal allocatBlanceTaxMny) {
        this.allocatBlanceTaxMny = allocatBlanceTaxMny;
    }

    public BigDecimal getNetWorthTax() {
        return netWorthTax;
    }

    public void setNetWorthTax(BigDecimal netWorthTax) {
        this.netWorthTax = netWorthTax;
    }

    public BigDecimal getNetWorthTaxRate() {
        return netWorthTaxRate;
    }

    public void setNetWorthTaxRate(BigDecimal netWorthTaxRate) {
        this.netWorthTaxRate = netWorthTaxRate;
    }
}

==> ejc-assistrmat-impl-3.0.0-20220411.111544-65-sources.jar: com/ejianc/business/assist/ownrmat/bean/AllotInDetailEntity.java <==
package com.ejianc.business.assist.ownrmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 周转材调入明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_assistownrmat_allot_in_detail")
public class AllotInDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="allocat_id")
    private Long allocatId; // 主表id
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类id
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value="material_id")
    private Long materialId; // 物资id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_spec")
    private String materialSpec; // 规格型号
    @TableField(value="material_unit_id")
    private Long materialUnitId; // 物资计量单位id
    @TableField(value="material_unit")
    private String materialUnit; // 物资计量单位
    @TableField(value="surplus_num")
    private BigDecimal surplusNum; // 剩余可用数量
    @TableField(value="allocat_num")
    private BigDecimal allocatNum; // 调拨数量
    @TableField(value="allocat_price")
    private BigDecimal allocatPrice; // 调拨单价
    @TableField(value="allocat_tax_price")
    private BigDecimal allocatTaxPrice; // 调拨单价（有税）
    @TableField(value="allocat_tax_rate")
    private BigDecimal allocatTaxRate; // 调拨税率
    @TableField(value="allocat_mny")
    private BigDecimal allocatMny; // 调拨金额
    @TableField(value="allocat_tax_mny")
    private BigDecimal allocatTaxMny; // 调拨单价（有税）
    @TableField(value="allocat_tax")
    private BigDecimal allocatTax; // 调拨税额
    @TableField(value="in_store_average_price")
    private BigDecimal inStoreAveragePrice; // 入库均价
    @TableField(value="in_store_tax")
    private BigDecimal inStoreTax; // 入库税额
    @TableField(value="in_store_mny")
    private BigDecimal inStoreMny; // 入库金额
    @TableField(value="in_store_tax_mny")
    private BigDecimal inStoreTaxMny; // 入库金额（有税）
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="in_store_tax_rate")
    private BigDecimal inStoreTaxRate; // 入库税率

    @TableField(value="net_worth_tax_mny")
    private BigDecimal netWorthTaxMny; // 材料净值(含税)
    @TableField(value="net_worth_mny")
    private BigDecimal netWorthMny; // 材料净值(无税)
    @TableField(value="original_value_tax_price")
    private BigDecimal originalValueTaxPrice; // 原值单价(含税)
    @TableField(value="original_value_price")
    private BigDecimal originalValuePrice; // 原值单价(无税)
    @TableField(value="original_value_tax_mny")
    private BigDecimal originalValueTaxMny; // 材料原值(含税)
    @TableField(value="original_value_mny")
    private BigDecimal originalValueMny; // 材料原值(无税)
    @TableField(value="on_hand_num")
    private BigDecimal onHandNum; // 在场数量
    @TableField(value="allocat_blance_mny")
    private BigDecimal allocatBlanceMny; // 调拨差额(无税)
    @TableField(value="allocat_blance_tax_mny")
    private BigDecimal allocatBlanceTaxMny; // 调拨差额
    @TableField(value="net_worth_tax")
    private BigDecimal netWorthTax; // 材料税额
    @TableField(value="net_worth_tax_rate")
    private BigDecimal netWorthTaxRate; // 材料税率
    

    public Long getAllocatId() {
        return allocatId;
    }

    public void setAllocatId(Long allocatId) {
        this.allocatId = allocatId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public Long getMaterialUnitId() {
        return materialUnitId;
    }

    public void setMaterialUnitId(Long materialUnitId) {
        this.materialUnitId = materialUnitId;
    }
    public String getMaterialUnit() {
        return materialUnit;
    }

    public void setMaterialUnit(String materialUnit) {
        this.materialUnit = materialUnit;
    }
    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }
    public BigDecimal getAllocatNum() {
        return allocatNum;
    }

    public void setAllocatNum(BigDecimal allocatNum) {
        this.allocatNum = allocatNum;
    }
    public BigDecimal getAllocatPrice() {
        return allocatPrice;
    }

    public void setAllocatPrice(BigDecimal allocatPrice) {
        this.allocatPrice = allocatPrice;
    }
    public BigDecimal getAllocatTaxPrice() {
        return allocatTaxPrice;
    }

    public void setAllocatTaxPrice(BigDecimal allocatTaxPrice) {
        this.allocatTaxPrice = allocatTaxPrice;
    }
    public BigDecimal getAllocatTaxRate() {
        return allocatTaxRate;
    }

    public void setAllocatTaxRate(BigDecimal allocatTaxRate) {
        this.allocatTaxRate = allocatTaxRate;
    }
    public BigDecimal getAllocatMny() {
        return allocatMny;
    }

    public void setAllocatMny(BigDecimal allocatMny) {
        this.allocatMny = allocatMny;
    }
    public BigDecimal getAllocatTaxMny() {
        return allocatTaxMny;
    }

    public void setAllocatTaxMny(BigDecimal allocatTaxMny) {
        this.allocatTaxMny = allocatTaxMny;
    }
    public BigDecimal getAllocatTax() {
        return allocatTax;
    }

    public void setAllocatTax(BigDecimal allocatTax) {
        this.allocatTax = allocatTax;
    }
    public BigDecimal getInStoreAveragePrice() {
        return inStoreAveragePrice;
    }

    public void setInStoreAveragePrice(BigDecimal inStoreAveragePrice) {
        this.inStoreAveragePrice = inStoreAveragePrice;
    }
    public BigDecimal getInStoreTax() {
        return inStoreTax;
    }

    public void setInStoreTax(BigDecimal inStoreTax) {
        this.inStoreTax = inStoreTax;
    }
    public BigDecimal getInStoreMny() {
        return inStoreMny;
    }

    public void setInStoreMny(BigDecimal inStoreMny) {
        this.inStoreMny = inStoreMny;
    }
    public BigDecimal getInStoreTaxMny() {
        return inStoreTaxMny;
    }

    public void setInStoreTaxMny(BigDecimal inStoreTaxMny) {
        this.inStoreTaxMny = inStoreTaxMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getInStoreTaxRate() {
        return inStoreTaxRate;
    }

    public void setInStoreTaxRate(BigDecimal inStoreTaxRate) {
        this.inStoreTaxRate = inStoreTaxRate;
    }

    public BigDecimal getNetWorthTaxMny() {
        return netWorthTaxMny;
    }

    public void setNetWorthTaxMny(BigDecimal netWorthTaxMny) {
        this.netWorthTaxMny = netWorthTaxMny;
    }

    public BigDecimal getNetWorthMny() {
        return netWorthMny;
    }

    public void setNetWorthMny(BigDecimal netWorthMny) {
        this.netWorthMny = netWorthMny;
    }

    public BigDecimal getOriginalValueTaxPrice() {
        return originalValueTaxPrice;
    }

    public void setOriginalValueTaxPrice(BigDecimal originalValueTaxPrice) {
        this.originalValueTaxPrice = originalValueTaxPrice;
    }

    public BigDecimal getOriginalValuePrice() {
        return originalValuePrice;
    }

    public void setOriginalValuePrice(BigDecimal originalValuePrice) {
        this.originalValuePrice = originalValuePrice;
    }

    public BigDecimal getOriginalValueTaxMny() {
        return originalValueTaxMny;
    }

    public void setOriginalValueTaxMny(BigDecimal originalValueTaxMny) {
        this.originalValueTaxMny = originalValueTaxMny;
    }

    public BigDecimal getOriginalValueMny() {
        return originalValueMny;
    }

    public void setOriginalValueMny(BigDecimal originalValueMny) {
        this.originalValueMny = originalValueMny;
    }

    public BigDecimal getOnHandNum() {
        return onHandNum;
    }

    public void setOnHandNum(BigDecimal onHandNum) {
        this.onHandNum = onHandNum;
    }

    public BigDecimal getAllocatBlanceMny() {
        return allocatBlanceMny;
    }

    public void setAllocatBlanceMny(BigDecimal allocatBlanceMny) {
        this.allocatBlanceMny = allocatBlanceMny;
    }

    public BigDecimal getAllocatBlanceTaxMny() {
        return allocatBlanceTaxMny;
    }

    public void setAllocatBlanceTaxMny(BigDecimal allocatBlanceTaxMny) {
        this.allocatBlanceTaxMny = allocatBlanceTaxMny;
    }

    public BigDecimal getNetWorthTax() {
        return netWorthTax;
    }

    public void setNetWorthTax(BigDecimal netWorthTax) {
        this.netWorthTax = netWorthTax;
    }

    public BigDecimal getNetWorthTaxRate() {
        return netWorthTaxRate;
    }

    public void setNetWorthTaxRate(BigDecimal netWorthTaxRate) {
        this.netWorthTaxRate = netWorthTaxRate;
    }
}
